Filters the requested model list based on whether the independent variable is log-transformed (which makes loglogistic4 redundant with logistic4).
Filters the requested model list based on whether the independent variable is log-transformed (which makes loglogistic4 redundant with logistic4).