Validate a Fixed Lower Asymptote Before Log Transformation
Source:R/transforms.R
validate_fixed_lower_asymptote.RdChecks that the value is a positive, finite scalar suitable for log10().
Returns the value if valid, NULL otherwise.
R/transforms.R
validate_fixed_lower_asymptote.RdChecks that the value is a positive, finite scalar suitable for log10().
Returns the value if valid, NULL otherwise.