Determines whether the lower asymptote a should be fixed based on
the constraint method. Returns the fixed value (on the raw scale,
before any log-transform) or NULL if a should be estimated freely.
Details
The constraint method controls behaviour:
"default"ais always free (returns NULL)."user_defined"ais fixed atl_asy_min_constraint(which should equall_asy_max_constraint)."range_of_blanks"ais fixed atl_asy_min_constraint. The caller is responsible for computing this from blank data upstream."geometric_mean_of_blanks"ais fixed atl_asy_min_constraint. The caller is responsible for computing this from blank data upstream.